 


Django Reports Creator
===================

django-reports-creator is a Django application and library for reports integrated with highcharts.


[![Build Status](https://travis-ci.org/bytcode/django-reports-creator.png)](https://travis-ci.org/bytcode/django-reports-creator)

--------------------------------------------------------------------


Documentation
=============

https://django-reports-creator.readthedocs.org/en/latest/

Contribute
==========

Clone the repo and help to be better this app :)
